BFGraph: preAllocMinHashResultIterator< HF > Struct Template Reference

BFGraph

Public Member Functions | Data Fields
preAllocMinHashResultIterator< HF > Struct Template Reference

## Public Member Functions
| preAllocMinHashResultIterator (const preAllocMinHashIterator< HF > &_p)
bool | operator== (const preAllocMinHashResultIterator &o) const
bool | operator!= (const preAllocMinHashResultIterator &o) const
preAllocMinHashResultIterator & | operator++ ()
preAllocMinHashResultIterator | operator++ (int)
preAllocMinHashResultIterator & | operator= (const preAllocMinHashResultIterator &o)
const minHashResult & | operator* () const
const minHashResult * | operator-> () const

## Data Fields
const preAllocMinHashIterator< HF > * | p
bool | invalid
size_t | p_it
size_t | p_it_end
const int | p_pos
const char * | p_s

The documentation for this struct was generated from the following file:

- src/minHashIterator.hpp